<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://postapi.lt
 * @since      1.0.0
 *
 * @package    Postapi
 * @subpackage Postapi/admin
 */

/**
 * The settings functionality of the plugin.
 *
 *
 * @package    Postapi
 * @subpackage Postapi/admin
 * @author     postapi.lt <info@postapi.lt>
 */
class Postapi_Settings {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Settings.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $settings;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

        $this->initialize_options();
	}

    public function setup_plugin_options_menu() {
        //Add the menu to the Plugins set of menu items
        add_options_page(
            __('PostAPI.lt settings', 'postapi'), 					// The title to be displayed in the browser window for this page.
            __('PostAPI.lt settings', 'postapi'),					// The text to be displayed for this menu item
            'manage_options',					// Which type of users can see this menu item
            'postapi-settings',			// The unique ID - that is, the slug - for this menu item
            array( $this, 'render_settings_page_content')				// The name of the function to call when rendering this menu's page
        );
    }

    public function filter_add_action_links($links) {
        $settings_link = [
            '<a href="' . admin_url( 'options-general.php?page=postapi-settings') . '">' . __('Settings', 'postapi') . '</a>',
        ];
        return array_merge($settings_link, $links);
    }

    /**
     * Renders a simple page to display for the menu defined above.
     */
    public function render_settings_page_content( $active_tab = '' )
    {
        $check_prerequisites_result = Postapi_Helper::is_woocommerce_enabled();
        $woocommerce_not_enabled_text = __('Woocommerce is not in activated on your Wordpress.', 'postapi');
        if($check_prerequisites_result !== true)
        {
            echo "<div class=\"notice notice-error\"> 
                <p><strong>{$woocommerce_not_enabled_text}</strong></p>
            </div>";

            return;
        }

        $url = '<a href="https://postapi.lt" target="_blank">PostAPI.lt</a>';
        $html_code = '<i>&lt;div class="clearfix postapi_txt"&gt;Pašto kodų integracija - &lt;a href="https://postapi.lt" target="_blank"&gt;PostAPI.lt&lt;/a&gt;&lt;/div&gt;</i>';

        $text_line1 = __('If you are using free PostAPI.lt key following promotional text MUST be added below postcode or address field - "Pašto kodų integracija - PostAPI.lt".', 'postapi');
        $text_line2 = sprintf(__('In most cases it is done automatically by this plugin itself. If not, please add this HTML code to your checkout form: %s', 'postapi'), $html_code);
        $text_line3 = __('Using free PostAPI.lt key without visible promotional text is forbidden.', 'postapi');

        $text_line1 = str_replace('PostAPI.lt', $url, $text_line1);
        $text_line3 = str_replace('PostAPI.lt', $url, $text_line3);

        ?>

        <div class="notice notice-warning">
            <p>
                <strong>
                    <?=$text_line1;?>
                    <?=$text_line2;?>
                    <br/><br/>
                    <?=$text_line3;?>
                </strong>
            </p>
        </div>

        <div class="wrap">
            <h2><a href="https://postapi.lt" target="_blank"><img id="postapi_logo" src="<?=plugin_dir_url( __FILE__ )."img/logo.png";?>"></a><?php _e( 'settings', 'postapi' ); ?></h2><br/>

            <form method="post" action="options.php" id="postapi-settings-form">
                <?php
                    settings_fields( 'postapi-settings' );
                    do_settings_sections( 'postapi-settings' );
                    submit_button();
                ?>
            </form>
        </div>
        <?php
    }


    public function initialize_postapi_options()
    {
        add_settings_section(
            'postapi_settings_section',			// ID used to identify this section and with which to register options
            null,		// Title to be displayed on the administration page
            null,	// Callback used to render the description of the section
            'postapi-settings'		// Page on which to add this section of options
        );

        add_settings_field(
            'free_key',
            __( 'Are you using free PostAPI.lt key?', 'postapi' ),
            array( $this, 'input_select_callback'),
            'postapi-settings',
            'postapi_settings_section',
            array(
                'postapi_settings',
                'free_key',
                (int)$this->settings['free_key'],
                '',
                array('1' => __( 'Yes', 'postapi' ), '0' => __( 'No', 'postapi' ),)
            )
        );

        add_settings_field(
            'api_key',
            __('Provided API key', 'postapi'),
            array( $this, 'input_textbox_callback'),
            'postapi-settings',
            'postapi_settings_section',
            array(
                'postapi_settings',
                'api_key',
                $this->settings['api_key'],
            )
        );

        add_settings_field(
            'postcode_prefix',
            __('Postcode prefix', 'postapi'),
            array( $this, 'input_textbox_callback'),
            'postapi-settings',
            'postapi_settings_section',
            array(
                'postapi_settings',
                'postcode_prefix',
                $this->settings['postcode_prefix'],
            )
        );

        register_setting(
            'postapi-settings',
            'postapi_settings',
            array($this, 'validate_api_settings')
        );

    }

    public function initialize_options()
    {
        $this->settings = get_option( 'postapi_settings' );
        if( false == $this->settings)
        {
            $default_data = [
                'free_key' => 1,
                'api_key' => '',
                'postcode_prefix' => 'LT-'
            ];

            add_option( 'postapi_settings', $default_data );
            $this->settings = get_option( 'postapi_settings' );
        }
    }

    // $args:
    // 0 - options name,
    // 1 - field,
    // 2 - value,
    // 3 - additional text
    // 4 - array for select/radio

    public function input_textbox_callback($args)
    {
        if( isset( $args[2] ) ) {
            $value = esc_sql( $args[2] );
        }

        $html = '<input type="text" id="'  . $args[1] . '" name="' . $args[0] . '['  . $args[1] . ']" placeholder="'.$args[3].'" value="' . $value . '" />';
        //$html .= '<label for="'  . $args[1] . '">&nbsp;'  . $args[3] . '</label>';

        echo $html;
    }

    public function input_select_callback($args)
    {
        $html = '<select id="'  . $args[1] . '" name="' . $args[0].'['.$args[1].']" '.(isset($args[5]) ? $args[5] : '').'>';

        if (is_array($args[4]))
        {
            foreach ($args[4] as $key=>$value)
                $html .= '<option value="'.$key.'"' . selected( $args[2], $key, false) . '>' . __( $value, 'woocommerce-inbank-lt' ) . '</option>';
        }

        $html .= '</select>';
        $html .= '<label for="'  . $args[1] . '">&nbsp;'  . $args[3] . '</label>';

        echo $html;
    }

}
