<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://postapi.lt
 * @since      1.0.0
 *
 * @package    Postapi
 * @subpackage Postapi/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Postapi
 * @subpackage Postapi/public
 * @author     postapi.lt <info@postapi.lt>
 */
class Postapi_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Postapi_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Postapi_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

        $wp_scripts = wp_scripts();
        $jquery_version = isset($wp_scripts->registered['jquery-ui-core']) ? $wp_scripts->registered['jquery-ui-core']->ver : '1.11.4';
        $style_url = 'https://ajax.googleapis.com/ajax/libs/jqueryui/' . $jquery_version . '/themes/smoothness/jquery-ui.css';
        wp_enqueue_style('postapi-jquery-ui', $style_url, false, $this->version);
        
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/postapi-public.css', array(), $this->version, 'all' );
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Postapi_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Postapi_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

        // retrieve data for js
        $postapi_data = $this->init();
        if (empty($postapi_data))
            return;

        // script should be loaded only on checkout
        if (!function_exists('is_checkout') || !is_checkout())
            return;

        wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/postapi-public.js', array( 'jquery', 'jquery-ui-autocomplete' ), $this->version, true );
        wp_add_inline_script( $this->plugin_name, 'var postapi_data = ' . wp_json_encode( $postapi_data ), 'before' );

        $this->enqueue_styles();
    }

    public function init()
    {
        // if woocommerce not enabled - PostAPI will not work
        if (Postapi_Helper::is_woocommerce_enabled() === false)
            return false;

        $options = get_option( 'postapi_settings' );

        // if api key is not entered - PostAPI will not work
        if (empty($api_key = $options['api_key']))
            return false;

        $api_token = Postapi_Helper::generate_api_token($api_key);
        if (empty($api_token))
            return false;

        $is_free = isset($options['free_key']) ? (int)$options['free_key'] > 0 : true;
        $postcode_prefix = isset($options['postcode_prefix']) ? $options['postcode_prefix'] : '';

        return [
            'api_url' => 'https://api.postapi.lt/api.php',
            'token' => $api_token,
            'is_free' => $is_free,
            'prefix' => $postcode_prefix
        ];
    }

}
